@@ -232,4 +232,14 @@ class CoreService(ClusterService):
                 else:
                     yield (ep, True, 'OK')
         finally:
-            self._endpoints = all_endpoints
\ No newline at end of file
+            self._endpoints = all_endpoints
+
+    def permissions(self):
+        perms = self.get('/permissions')
+        for perm in perms:
+            path = ':'.join(['<{}>'.format(p['name']) if p['type'] == 'DYNAMIC' else p['name'] for p in perm['parts']])
+            path_comments = ', '.join([p['comment'] for p in perm['parts'] if p['comment']])
+            perm['path'] = path
+            perm['path_comments'] = path_comments
+
+        return perms
